Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Agent ¶
type Agent struct {
// contains filtered or unexported fields
}
Agent is the core component that runs on each node. It periodically pulls the desired state from the config store and reconciles it with the actual state of running Firecracker microVMs.
func (*Agent) MetricsText ¶
MetricsText returns the Prometheus text exposition for agent runtime metrics.
Click to show internal directories.
Click to hide internal directories.